@@ -5,6 +5,9 @@ if [ "$#" -eq 1 ]; then
   instance=$1
 fi
 
+export PANDA_BEHIND_REAL_LB=true
+#  export PANDA_SYS=/opt/idds/
+
 if [ "$instance" == "k8s" ]; then
     export PANDA_AUTH=oidc
     export PANDA_URL_SSL=https://pandaserver-doma.cern.ch:25443/server/panda
